@@ -28,6 +28,7 @@
 #ifdef SEARDUINO_STUB
 #define ENABLE_SLEEP
 #include "setup.h"
+#include "searduino_pin.h"
 #include <stdio.h>
 #else
 #undef ENABLE_SLEEP
@@ -43,5 +44,13 @@
 #endif
 
 
+#ifdef  SEARDUINO_STUB
+#define SEARDUINO_DEBUG(a)  fprintf(stder, "[SEARDUINO DEBUG %s:%d:%s]:  ",__FILE__,__LINE__,__func__); printf a; printf ("\n");
+#else
+#define SEARDUINO_DEBUG(a)
+#endif  /* SEARDUINO_STUB */
+ 
+
+
 
 #endif /* ARDUINO_EXTRAS_SETUP_H*/
